#[non_exhaustive]pub enum AuthStatus {
Loading,
SignedOut,
SignedIn,
}Expand description
Resolved authentication status for app-facing rendering decisions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Loading
Clerk has not supplied a reliable auth answer yet.
SignedOut
Clerk has resolved and no active session is known.
SignedIn
A signed-in session is known, either from SSR initial state or clerk-js.
Implementations
Sourceimpl AuthStatus
impl AuthStatus
Sourcepub fn is_loading(self) -> bool
pub fn is_loading(self) -> bool
True while auth has not resolved to signed-in or signed-out yet.
Sourcepub fn is_signed_out(self) -> bool
pub fn is_signed_out(self) -> bool
True only when auth has resolved and no active session is known.
Sourcepub fn is_signed_in(self) -> bool
pub fn is_signed_in(self) -> bool
True when a signed-in session is known.