#[non_exhaustive]pub enum VerificationOutcome {
Missing,
Valid(ClerkAuth),
Invalid(InvalidTokenReason),
Unavailable,
}Expand description
Result of checking request credentials before handlers or server functions run.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Missing
No bearer credentials or session cookie were present on the request.
Valid(ClerkAuth)
Credentials were present and verified.
Invalid(InvalidTokenReason)
Credentials were present but invalid.
Verification infrastructure was unavailable. Server middleware fails closed.
Implementations