pub struct TaskSetupMFAOptions { /* private fields */ }Expand description
Options for the Clerk task setup-MFA UI.
Implementations
Sourceimpl TaskSetupMFAOptions
impl TaskSetupMFAOptions
Sourcepub fn from_value(value: Value) -> Self
pub fn from_value(value: Value) -> Self
Wrap an already-built JSON value.
Sourcepub fn option(self, key: impl Into<String>, value: impl Into<Value>) -> Self
pub fn option(self, key: impl Into<String>, value: impl Into<Value>) -> Self
Set a raw clerk-js option by its JavaScript key.
If the wrapped value is not a JSON object, it is replaced with an empty object before the key is set.
Sourcepub fn into_value(self) -> Value
pub fn into_value(self) -> Value
Convert into the raw JSON value passed to clerk-js.
Sourceimpl TaskSetupMFAOptions
impl TaskSetupMFAOptions
Sourcepub fn redirect_url_complete(self, value: impl Into<String>) -> Self
pub fn redirect_url_complete(self, value: impl Into<String>) -> Self
Set the URL Clerk navigates to after all pending session tasks resolve.
Sourcepub fn appearance(self, value: Value) -> Self
pub fn appearance(self, value: Value) -> Self
Forward Clerk’s raw appearance object.