#[non_exhaustive]pub enum TestIssuerError {
KeyFile {
path: PathBuf,
source: Error,
},
Key(String),
Sign(String),
OrganizationPermission(String),
Layer(String),
}Available on crate feature
testing only.Expand description
Something went wrong minting a test token or loading a test key.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
KeyFile
The key file could not be read or written.
Fields
Key(String)
The key could not be generated, parsed, or serialized.
Sign(String)
The token could not be signed.
OrganizationPermission(String)
A session was built with organization permissions that are not in
Clerk’s org:<feature>:<permission> form.
Layer(String)
The auth layer could not be built from this issuer’s keys.